==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-PT/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Esse campo não existe.',
        'already_added'   => 'Campo já adicionado',

        'create' => array(
            'error'   => 'Campo não criado. Por favor tente novamente.',
            'success' => 'Campo criado com sucesso.',
            'assoc_success' => 'Campo adicionado ao conjunto de campos com sucesso.'
        ),

        'update' => array(
            'error'   => 'Campo não foi atualizado, por favor tente de novamente',
            'success' => 'Campo atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem a certeza que deseja eliminar este campo?',
            'error'   => 'Ocorreu um problema ao remover o campo. Por favor tente novamente.',
            'success' => 'O campo foi apagado com sucesso.',
            'in_use'   => 'Campo continua em uso.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Fieldset não existe',

        'create' => array(
            'error'   => 'O Conjunto de campos não foi criado, por favor tente novamente.',
            'success' => 'Conjunto de campos criado com sucesso.'
        ),

        'update' => array(
            'error'   => 'Conjunto de campos não foi atualizado, por favor tente novamente',
            'success' => 'Conjunto de campos atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem a certeza que deseja eliminar este conjunto de campos?',
            'error'   => 'Ocorreu um problema ao apagar o conjunto de campos. Por favor tente novamente.',
            'success' => 'O conjunto de campos foi eliminado com sucesso.',
            'in_use'   => 'Conjunto de campos continua em uso.',
        )

    ),






);

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/pt-PT/admin/custom_fields/message.php <==
<?php

return array(

    'field' => array(
        'invalid'   => 'Esse campo não existe.',
        'already_added'   => 'Campo já adicionado',

        'create' => array(
            'error'   => 'Campo não criado. Por favor tente novamente.',
            'success' => 'Campo criado com sucesso.',
            'assoc_success' => 'Campo adicionado ao conjunto de campos com sucesso.'
        ),

        'update' => array(
            'error'   => 'Campo não foi atualizado, por favor tente de novamente',
            'success' => 'Campo atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem a certeza que deseja eliminar este campo?',
            'error'   => 'Ocorreu um problema ao remover o campo. Por favor tente novamente.',
            'success' => 'O campo foi apagado com sucesso.',
            'in_use'   => 'Campo continua em uso.',
        )

    ),

    'fieldset' => array(

        'does_not_exist' => 'Fieldset não existe',

        'create' => array(
            'error'   => 'O Conjunto de campos não foi criado, por favor tente novamente.',
            'success' => 'Conjunto de campos criado com sucesso.'
        ),

        'update' => array(
            'error'   => 'Conjunto de campos não foi atualizado, por favor tente novamente',
            'success' => 'Conjunto de campos atualizado com sucesso.'
        ),

        'delete' => array(
            'confirm'   	=> 'Tem a certeza que deseja eliminar este conjunto de campos?',
            'error'   => 'Ocorreu um problema ao apagar o conjunto de campos. Por favor tente novamente.',
            'success' => 'O conjunto de campos foi eliminado com sucesso.',
            'in_use'   => 'Conjunto de campos continua em uso.',
        )

    ),

    'fieldset_default_value' => array(

        'error' => 'Erro ao validar valores padrão do conjunto de campos.',

    ),






);
